require 'thor'

module CropDuster
  class CLI < Thor

    desc "migrate", "Migrate the database to the latest version"
    option :db, required: true
    def migrate
      CropDuster.configure do |config|
        config.db = options[:db]
      end

      ActiveRecord::Migration.verbose = true
      ActiveRecord::Migrator.migrate File.join(File.dirname(__FILE__), "..", "..", "db", "migrate")
    end

    desc "import", "Migrate the database to the latest version"
    option :db, required: true
    option :aws_secret, required: true
    option :aws_key, required: true
    option :aws_billing_bucket
    option :tmp_dir
    def import
      set_configs(options[:db], options[:aws_secret], options[:aws_key], options[:aws_billing_bucket], options[:tmp_dir])
      CropDuster::Importer.import
    end

    desc "import_billing", "Imports billing information from AWS"
    option :db, required: true
    option :aws_secret, required: true
    option :aws_key, required: true
    option :aws_billing_bucket, required: true
    option :tmp_dir
    def import_billing
      set_configs(options[:db], options[:aws_secret], options[:aws_key], options[:aws_billing_bucket], options[:tmp_dir])
      CropDuster::Importer.import_billing
    end

    private
    def set_configs(db_url, aws_secret, aws_key, aws_billing_bucket = nil, tmp_dir = "/tmp")
      CropDuster.configure do |config|
        config.db                 = db_url
        config.aws_secret         = aws_secret
        config.aws_key            = aws_key
        config.aws_billing_bucket = aws_billing_bucket
        config.tmp_dir            = tmp_dir
      end
    end
  end
end
